import React, { Component } from "react";
import { withTheme, withStyles } from "@material-ui/core/styles";
import { connect } from "react-redux";
import { bindActionCreators } from "redux";
import { injectIntl } from 'react-intl';
import { formatMessageWithValues } from "@openimis/fe-core";
import { fetchMyEntities } from "../actions";
import { ProgressOrError, Table } from "@openimis/fe-core";

const styles = theme => ({
    page: theme.page,
});

class MyEntitiesPage extends Component {

    state = {
        page: 0,
        pageSize: 10,
        afterCursor: null,
        beforeCursor: null,
    }

    componentDidMount() {
        this.query();
    }

    query = () => {
        let prms = [];
        prms.push(`first: ${this.state.pageSize}`);
        if (!!this.state.afterCursor) {
            prms.push(`after: "${this.state.afterCursor}"`)
        }
        if (!!this.state.beforeCursor) {
            prms.push(`before: "${this.state.beforeCursor}"`)
        }
        prms.push(`orderBy: ["code"]`);
        this.props.fetchMyEntities(prms);
    }

    render() {
        const { intl, classes, fetchingMyEntities, errorMyEntities, myEntities, myEntitiesPageInfo } = this.props;


        let headers = [
            "my_module.code",
            "my_module.name",
        ]

        let itemFormatters = [
            e => e.code,
            e => e.name,
        ]

        return (
            <div className={classes.page}>
                <ProgressOrError progress={fetchingMyEntities} error={errorMyEntities} />
                <Table
                    module="my_module"
                    header={formatMessageWithValues(intl, "my_module", "my_entities.table", {count: myEntitiesPageInfo.totalCount})}
                    headers={headers}
                    itemFormatters={itemFormatters}
                    items={myEntities}
                    withPagination={true}
                    page={this.state.page}
                    pageSize={this.state.pageSize}
                    count={myEntitiesPageInfo.totalCount}
                    onChangePage={this.onChangePage}
                    onChangeRowsPerPage={this.onChangeRowsPerPage}
                    rowsPerPageOptions={this.rowsPerPageOptions}
                />
            </div>
        )
    }
}

const mapStateToProps = state => ({
    fetchingMyEntities: state.my_module.fetchingMyEntities,
    errorMyEntities: state.my_module.errorMyEntities,
    fetchedMyEntities: state.my_module.fetchedMyEntities,
    myEntities: state.my_module.myEntities,
    myEntitiesPageInfo: state.my_module.myEntitiesPageInfo,
});

const mapDispatchToProps = dispatch => {
    return bindActionCreators({ fetchMyEntities }, dispatch);
};

export default injectIntl(withTheme(withStyles(styles)(connect(mapStateToProps, mapDispatchToProps)(MyEntitiesPage))));